const electron = require('electron');

function _interopNamespaceDefault(e) {
    const n = Object.create(null);
    if (e) {
        for (const k in e) {
            n[k] = e[k];
        }
    }
    n.default = e;
    return n;
}

const electron__namespace = /*#__PURE__*/_interopNamespaceDefault(electron);

var IPCChannel;
(function (IPCChannel) {
    /** IPC to check main process is listening */
    IPCChannel["RENDERER_START"] = "sentry-electron.renderer-start";
    /** IPC to send a captured event to Sentry. */
    IPCChannel["EVENT"] = "sentry-electron.event";
    /** IPC to pass scope changes to main process. */
    IPCChannel["SCOPE"] = "sentry-electron.scope";
    /** IPC to pass envelopes to the main process. */
    IPCChannel["ENVELOPE"] = "sentry-electron.envelope";
    /** IPC to pass renderer status updates */
    IPCChannel["STATUS"] = "sentry-electron.status";
})(IPCChannel || (IPCChannel = {}));

/**
 * This preload script may be used with sandbox mode enabled which means regular require is not available.
 */
// eslint-disable-next-line no-restricted-globals
if (window.__SENTRY_IPC__) {
    // eslint-disable-next-line no-console
    console.log('Sentry Electron preload has already been run');
}
else {
    electron.crashReporter.start({
        companyName: '',
        ignoreSystemCrashHandler: true,
        // This script is only ever used for Electron < v9 where the remote module is available
        // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
        productName: electron__namespace.remote.app.name || electron__namespace.remote.app.getName(),
        submitURL: '',
        uploadToServer: false,
    });
    const ipcObject = {
        sendRendererStart: () => electron.ipcRenderer.send(IPCChannel.RENDERER_START),
        sendScope: (scopeJson) => electron.ipcRenderer.send(IPCChannel.SCOPE, scopeJson),
        sendEvent: (eventJson) => electron.ipcRenderer.send(IPCChannel.EVENT, eventJson),
        sendEnvelope: (envelope) => electron.ipcRenderer.send(IPCChannel.ENVELOPE, envelope),
        sendStatus: (status) => electron.ipcRenderer.send(IPCChannel.STATUS, status),
    };
    // eslint-disable-next-line no-restricted-globals
    window.__SENTRY_IPC__ = ipcObject;
    // We attempt to use contextBridge if it's available
    if (electron.contextBridge) {
        // This will fail if contextIsolation is not enabled
        try {
            electron.contextBridge.exposeInMainWorld('__SENTRY_IPC__', ipcObject);
        }
        catch (e) {
            //
        }
    }
}
//# sourceMappingURL=legacy.js.map
