const electron = require('electron');
const fetch = require('node-fetch');

const { Response } = jest.requireActual('node-fetch');

const { manualUpdate } = require('./manual');
const { sleep } = require('./utils');

jest.mock('electron', () => {
  return {
    app: {
      getVersion() {
        return '1.2.3';
      },
    },
    dialog: {
      showMessageBox: jest.fn(),
    },
    shell: {
      openExternal: jest.fn(),
    },
  };
});

jest.mock('node-fetch');

jest.mock('./package.json', () => {
  return {
    version: '1.2.3',
  };
});

test('manualUpdate', async () => {
  /* Fetch Error */

  fetch.mockRejectedValue('fetch error');

  let reporter = jest.fn();
  manualUpdate('https://update.example.org', '', 5, reporter);
  await sleep(100);
  expect(reporter).toBeCalledWith('fetch error');

  /* Invalid Status */

  fetch.mockResolvedValue(new Response('', { status: 400 }));

  reporter = jest.fn();
  manualUpdate('https://update.example.org', '', 5, reporter);
  await sleep(100);
  expect(reporter).toBeCalled();

  /* Invalid JSON */

  fetch.mockResolvedValue(new Response('foo'));

  reporter = jest.fn();
  manualUpdate('https://update.example.org', '', 5, reporter);
  await sleep(100);
  expect(reporter).toBeCalled();

  /* No Update */

  fetch.mockResolvedValue(Promise.resolve(new Response('', { status: 204 })));

  manualUpdate('https://update.example.org', '', 5, reporter);
  await sleep(100);

  /* Notification */

  fetch.mockResolvedValue(
    Promise.resolve(new Response('{ "url": "https://download.example.org/3.2.1", "name": "3.2.1" }'))
  );

  electron.dialog.showMessageBox.mockResolvedValue({ response: 0 });
  electron.shell.openExternal.mockResolvedValue(null);

  manualUpdate('https://update.example.org', '', 5, reporter);
  await sleep(100);

  expect(electron.dialog.showMessageBox).toBeCalledWith({
    type: 'info',
    title: 'Application Update',
    message: 'Version 3.2.1 is available.',
    detail: 'Download and install the new version now.',
    buttons: ['Download', 'Skip'],
    defaultId: 0,
  });

  expect(electron.shell.openExternal).toBeCalledWith('https://download.example.org/3.2.1');
});
